@@ -19,36 +19,36 @@
 
 
 TOUR <- function(x, method=NA, tsp=NULL){
-    if(inherits(x, "TOUR")) return(x)
-	
-    x <- as.TOUR(x)
-    attr(x, "method") <- as.character(method)
-    if(!is.null(tsp)){
-	attr(x, "tour_length") <- tour_length(tsp, x)
-	names(x) <- labels(tsp)[x]
-    }
-
-    x
+  if(inherits(x, "TOUR")) return(x)
+  
+  x <- as.TOUR(x)
+  attr(x, "method") <- as.character(method)
+  if(!is.null(tsp)){
+    attr(x, "tour_length") <- tour_length(x, tsp)
+    names(x) <- labels(tsp)[x]
+  }
+  
+  x
 }
 
 ## coercion
 as.TOUR <- function(object) UseMethod("as.TOUR")
 as.TOUR.numeric <-  function(object){
-    l <- labels(object)	    ### preserve lables
-    object <- as.integer(object)
-    names(object) <- l
-    as.TOUR(object)
+  l <- labels(object)	    ### preserve lables
+  object <- as.integer(object)
+  names(object) <- l
+  as.TOUR(object)
 }
 as.TOUR.integer <- function(object){
-
-    ## check tour
-    if(any(object < 1) || any(object > length(object)) || any(is.na(object))) 
-        stop("tour contains illegal elements.")
-
-    if(any(duplicated(object))) stop("tour indices are not unique.")
-
-    class(object) <- c("TOUR", class(object))
-    object
+  
+  ## check tour
+  if(any(object < 1) || any(object > length(object)) || any(is.na(object))) 
+    stop("tour contains illegal elements.")
+  
+  if(any(duplicated(object))) stop("tour indices are not unique.")
+  
+  class(object) <- c("TOUR", class(object))
+  object
 }
 
 
@@ -56,12 +56,12 @@ as.TOUR.integer <- function(object){
 ## helper for tour
 
 print.TOUR <- function(x, ...){
-
-   cat("object of class", sQuote(class(x)[1]), "\n")
-   cat("result of method", sQuote(attr(x, "method")), "for", 
-       length(x), "cities\n")
-   if(!is.null(attr(x, "tour_length")))
-   cat("tour length:", attr(x, "tour_length"), "\n")
-   else 
-   cat("tour length: unknown\n")
+  
+  cat("object of class", sQuote(class(x)[1]), "\n")
+  cat("result of method", sQuote(attr(x, "method")), "for", 
+    length(x), "cities\n")
+  if(!is.null(attr(x, "tour_length")))
+    cat("tour length:", attr(x, "tour_length"), "\n")
+  else 
+    cat("tour length: unknown\n")
 }
